@@ -1,11 +1,12 @@
+#' @importFrom dotCall64 integer_dc vector_dc numeric_dc
 sgl_ls <- function(
-  bn, bs, ix, iy, nobs, nvars, x, y, pf, pfl1, dfmax, pmax, nlam,
-  flmin, ulam, eps, maxit, vnames, group, intr, asparse, standardize,
-  lower_bnd, upper_bnd) {
+    bn, bs, ix, iy, nobs, nvars, x, y, pf, pfl1, dfmax, pmax, nlam,
+    flmin, ulam, eps, maxit, vnames, group, intr, asparse, standardize,
+    lower_bnd, upper_bnd) {
   # call Fortran core
   is.sparse <- FALSE
-  if (!is.numeric(y)) rlang::abort("For family = 'gaussian', y must be numeric.")
-  if (inherits(x,"sparseMatrix")) {
+  if (!is.numeric(y)) cli_abort("For family = 'gaussian', y must be numeric.")
+  if (inherits(x, "sparseMatrix")) {
     is.sparse <- TRUE
     x <- as_dgCMatrix(x)
   }
@@ -34,12 +35,14 @@ sgl_ls <- function(
   if (!is.sparse) {
     fit <- dotCall64::.C64(
       "sparse_four",
-      SIGNATURE = c("integer", "integer", "integer", "integer", "double",
-                    "integer", "integer", "double", "double", "double", "double",
-                    "integer", "integer", "integer", "double", "double",
-                    "double", "integer", "integer", "integer", "double", "double", "integer",
-                    "integer", "double", "integer", "integer", "double",
-                    "double", "double", "double"),
+      SIGNATURE = c(
+        "integer", "integer", "integer", "integer", "double",
+        "integer", "integer", "double", "double", "double", "double",
+        "integer", "integer", "integer", "double", "double",
+        "double", "integer", "integer", "integer", "double", "double", "integer",
+        "integer", "double", "integer", "integer", "double",
+        "double", "double", "double"
+      ),
       # Read only
       bn = bn, bs = bs, ix = ix, iy = iy, gam = gamma, nobs = nobs,
       nvars = nvars, x = as.double(x), y = as.double(y), pf = pf,
@@ -57,17 +60,20 @@ sgl_ls <- function(
       alsparse = asparse, lb = lower_bnd, ub = upper_bnd,
       INTENT = c(rep("r", 11), rep("rw", 8), rep("w", 9), rep("r", 3)),
       NAOK = TRUE,
-      PACKAGE = "sparsegl")
+      PACKAGE = "sparsegl"
+    )
   } else { # sparse design matrix
     fit <- dotCall64::.C64(
       "spmat_four",
-      SIGNATURE = c("integer", "integer", "integer", "integer", "double",
-                    "integer", "integer", "double", "integer", "integer",
-                    "integer", "double", "double", "double", "integer", "integer",
-                    "integer", "double", "double", "double", "integer",
-                    "integer", "integer", "double", "double", "integer",
-                    "integer", "double", "integer", "integer", "double",
-                    "double", "double", "double"),
+      SIGNATURE = c(
+        "integer", "integer", "integer", "integer", "double",
+        "integer", "integer", "double", "integer", "integer",
+        "integer", "double", "double", "double", "integer", "integer",
+        "integer", "double", "double", "double", "integer",
+        "integer", "integer", "double", "double", "integer",
+        "integer", "double", "integer", "integer", "double",
+        "double", "double", "double"
+      ),
       # Read only
       bn = bn, bs = bs, ix = ix, iy = iy, gam = gamma, nobs = nobs,
       nvars = nvars, x = as.double(xval), xidx = xidx, xcptr = xcptr,
@@ -84,7 +90,8 @@ sgl_ls <- function(
       alsparse = as.double(asparse), lb = lower_bnd, ub = upper_bnd,
       INTENT = c(rep("r", 14), rep("rw", 8), rep("w", 9), rep("r", 3)),
       NAOK = TRUE,
-      PACKAGE = "sparsegl")
+      PACKAGE = "sparsegl"
+    )
   }
 
   # output
